@@ -1,7 +1,7 @@
 use v5.12;
 
 package Chart;
-our $VERSION = 'v2.402.2';
+our $VERSION = 'v2.402.3';
 
 use Chart::Points;
 use Chart::Lines;
@@ -28,7 +28,7 @@ use Chart::Pareto;
 
 =head1 NAME
 
-Chart - a series of charting modules 
+Chart - a series of charting modules
 
 =head1 SYNOPSIS 
 
@@ -347,7 +347,7 @@ this hash are
 NB. For composite charts, there is a limit of 8 datasets per component.
 The colors for 'dataset8' through 'dataset15' become the colors
 for 'dataset0' through 'dataset7' for the second component chart.
-More option how to defin colors are listed under L<Chart::Color>.
+More options how to define colors are described under L<Chart::Color>.
 
 =item 'title_font'
 
@@ -449,9 +449,10 @@ chart.  Default is undef.
 
 =item 'y_ticks1', 'y_ticks2'
 
-The number of y ticks to use on the first and second y-axis on a composite
-chart.  Please note that if you just set the 'y_ticks' option, both axes 
-will use that number of y ticks.  Both default to undef.
+Only for composite charts, the number of y ticks to use on the first and
+second y-axis on a composite chart.  Please note that if you just set the
+'y_ticks' option, both axes will use that number of y ticks.
+Both default to undef.
 
 =item 'f_y_tick1', 'f_y_tick2'
 
