@@ -5,7 +5,7 @@
 use v5.12;
 
 package Chart::Color;
-our $VERSION = 'v2.402.2';
+our $VERSION = 'v2.402.3';
 
 use Carp;
 use Chart::Color::Constant;
@@ -83,6 +83,7 @@ sub blue        { $_[0][3] }
 sub hue         { $_[0][4] }
 sub saturation  { $_[0][5] }
 sub lightness   { $_[0][6] }
+sub string      { $_[0][0] ? $_[0][0] : "[ $_[0][1], $_[0][2], $_[0][3] ]" }
 
 sub hsl         { @{$_[0]}[4 .. 6] }
 sub rgb         { @{$_[0]}[1 .. 3] }
@@ -256,23 +257,23 @@ Chart::Color - read only single color holding objects
 
 =head1 DESCRIPTION
 
-This module is designed for internal usage. It handles all of users color
-definitions done with method "$chart->set({...})". But its educational,
-(even for the casual user), to see which formats are allowed to define
-colors. (see next chapter)
+This module is designed for internal usage. It handles also all color
+definitions done by users with method "$chart->set(color => {...})". 
+To see which formats are allowed there, read the next section and please
+note that ->set() handles only scalar values.
 
 =head1 CONSTRUCTOR
 
-When defining a color via "$chart->set( {background => $c});", 
-$c is a place holder for a scalar. Any multi value options displayed here
-are not available there and in other methods here.
+There are many options to create a color objects.  In short you can 
+either use the name of a predefined constant or provide values in RGB
+or HSL color space.
 
 =head2 new( 'name' )
 
 Get a color by providing a name from the X11 or HTML (SVG) standard or
 a Pantone report. Upper/Camel case will be treated as lower case and
 inserted underscore letters ('_') will be ignored as perl does in
-numbers (1_000 == 1000).
+numbers (1_000 == 1000) (see more under L<Chart::Color::Constant>).
 
     my $color = Chart::Color->new('Emerald');
     my @names = Chart::Color::Constant::all_names(); # select from these
@@ -280,7 +281,7 @@ numbers (1_000 == 1000).
 =head2 new( 'standard:color' )
 
 Get a color by name from a specific standard as provided by an external
-module Graphics::ColorNames::* , which has to be installed separately.
+module L<Graphics::ColorNames>::* , which has to be installed separately.
 * is a placeholder for the pallet name, which might be: Crayola, CSS,
 EmergyC, GrayScale, HTML, IE, SVG, Werner, WWW or X. In ladder case
 Graphics::ColorNames::X has to be installed.
@@ -342,6 +343,12 @@ The name will be found and filled in, even when the object is created
 with RGB or HSL values. If the color is not found in any of the mentioned
 standards, it returns an empty string.
 
+=head2 string
+
+String to reproduce color object by: Chart::Color->new (eval $string).
+It is either the name (if color has one) or the stringified triplet:
+"[ $red, $green, $blue ]".
+
 =head2 red
 
 Integer between 0 .. 255 describing the red portion in RGB space.
